@@ -177,7 +177,10 @@ class QAMProxy:
                  client_id=None,
                  serializer='pickle',
                  ssl=False):
-                 
+        self.publisher_thread = None
+        self.consumer_thread = None
+        self.callback_observer_thread = None
+        
         if client_id == None:
             self.client_id = str(uuid.uuid4())
         else:
@@ -185,9 +188,10 @@ class QAMProxy:
 
         logger.info('Init QAMProxy')
         self.serializer = serializer
-    
 
+       
 
+      
         self.amqp_credentials = AMQPCredentials(hostname=hostname,
                                                 port=port,
                                                 username=username,
@@ -195,27 +199,32 @@ class QAMProxy:
                                                 vhost=vhost,
                                                 ssl=ssl)
 
-   
+        
+        logger.debug('Pre Consumer Thread init')
         self.consumer_thread = ConsumerThread(amqp_credentials=self.amqp_credentials,
                                               server_id=server_id,
                                               client_id=self.client_id,
                                               serializer=self.serializer)
-
+        logger.debug('After Consumer Thread Init')
         self.publisher_thread = PublisherThread(amqp_credentials=self.amqp_credentials,
                                                 server_id=server_id,
                                                 client_id=self.client_id,
                                                 serializer=self.serializer)
-   
+        
+        logger.debug('After Publisher Thread Init')
         self.callback_observer_thread = CallbackObserverThread(self)
-
+        logger.debug('After CallbackObserver Thread Init')
 
         self.consumer_thread.setDaemon(True)
         self.publisher_thread.setDaemon(True)
         self.callback_observer_thread.setDaemon(True)
     
         self.consumer_thread.start()
+        logger.debug('After Consumer Thread Start')
         self.publisher_thread.start()
+        logger.debug('After Publisher Thread Start')
         self.callback_observer_thread.start()
+        logger.debug('After CallbackObserver Thread Start')
 
     def __del__(self):
         self.close()
@@ -304,6 +313,7 @@ class QAMProxy:
         :type param: list of parameters
         :rtype: result received from QAMServer
         """
+        logger.debug('Request: ' + repr(methodname) + '; Params: '+ repr(params))
         id = self.consumer_thread.get_free_result_list_id()
         #assemble message structure (dict) and send message
         self.publisher_thread.add_message_to_send({'id':id,
@@ -324,6 +334,8 @@ class QAMProxy:
         It is used for RPC, to get the function which should be called on the QAMServer.
         """
         # magic method dispatcher
+        logger.debug('Recursion: ' + name)
+        time.sleep(1)
         return _Method(self.__request, name)
 
 
@@ -510,17 +522,24 @@ class ConsumerThread(Thread):
         self.kill = False
         self.serializer = serializer
 
-        self.amqpconn = BrokerConnection(hostname=amqp_credentials.hostname,
+        try:
+            self.amqpconn = BrokerConnection(hostname=amqp_credentials.hostname,
                                        port=amqp_credentials.port,
                                        userid=amqp_credentials.username,
                                        password=amqp_credentials.password,
                                        virtual_host=amqp_credentials.vhost,
                                        ssl=amqp_credentials.ssl)
-
-        self.consumer = Consumer(connection=self.amqpconn,
+        except Exception:
+            logger.exception('Init BrokerConnection in ConsumerThread')
+            raise
+        try:
+            self.consumer = Consumer(connection=self.amqpconn,
                                  queue=client_id + '_client_queue',
                                  exchange=server_id + '_client_exchange',
                                  routing_key=client_id + '_client_routing_key')
+        except Exception:
+            logger.exception('Init Consumer in ConsumerThread')
+            raise
 
     def get_result_item(self, id):
         """
@@ -638,19 +657,22 @@ class ConsumerThread(Thread):
         he state in the result_list for specific results is set *DONE*.
         """
         while not self.kill:
-            message = self.consumer.fetch()
-            if message != None:
-                message.ack()
-                message_data = message.payload
-                result_id = message_data['id']
-
-                if self.result_list[result_id]['state'] != ConsumerThread.FREE:
-                    self.result_list[result_id]['result_message'] = message_data
-                    self.result_list[result_id]['state'] = ConsumerThread.DONE
-            else:
-                time.sleep(0.1)
+            try:
+                message = self.consumer.fetch()
+                if message != None:
+                    message.ack()
+                    message_data = message.payload
+                    result_id = message_data['id']
 
+                    if self.result_list[result_id]['state'] != ConsumerThread.FREE:
+                        self.result_list[result_id]['result_message'] = message_data
+                        self.result_list[result_id]['state'] = ConsumerThread.DONE
+                else:
+                    time.sleep(0.1)
 
+            except Exception:
+                logger.exception('Exception: Lost Connection during Fetch in Consumer Thread')
+                self.amqpconn.connection()
 #===========================================================================
 class PublisherThread(Thread):
     """
@@ -732,8 +754,15 @@ class PublisherThread(Thread):
                 time.sleep(0.1)
                 continue
             method_message = self.method_queue.pop(0)
-            self.publisher.send(method_message)
-   
+            try:
+                self.publisher.send(method_message)
+            except Exception, e:
+                logger.exception('Exception: During sending.')
+                self.method_queue.insert(0, method_message)
+                try:
+                    self.amqpconn.connect()
+                except Exception:
+                    logger.exeption('Exception: During connection a broken AMQP Connection')
     
 #===========================================================================
 
