@@ -74,6 +74,7 @@ class  QamTestCase(unittest.TestCase):
     def tearDown(self):
         self.server.close()
         self.server_pickle.close()
+        
     #    self.foo.dispose()
     #    self.foo = None
 
@@ -100,6 +101,25 @@ class  QamTestCase(unittest.TestCase):
 #
 #        proxy.close()
 
+    def test_connect_no_server(self):
+        print 'test_connect_no_server'
+        try:
+            proxy = QAMProxy(hostname=self.amqp_hostname+"_",
+                         port=self.amqp_port,
+                         username=self.amqp_user,
+                         password=self.amqp_pwd,
+                         vhost=self.amqp_vhost,
+                         server_id='testqamserver',
+                         client_id='testqamclient1',
+                         serializer='json'
+                         )
+            proxy.close()
+            
+        except Exception:
+            print 'Successfully catched ConnectionErrorException'
+            
+        
+
     def test_basic_method_call(self):
         print 'test_basic_method_call'
         proxy = QAMProxy(hostname=self.amqp_hostname,
@@ -798,7 +818,7 @@ class  QamTestCase(unittest.TestCase):
 if __name__ == '__main__':
     unittest.main()
 #    result = unittest.TestResult()
-#    test = QamTestCase('long_non_load_test')
+#    test = QamTestCase('test_connect_no_server')
 #    test.run(result)
 #    if len(result.failures) != 0: print "=============== Failures ==========================="
 #    print "".join("%s = %s" % (a, b) for a, b in result.failures)
